@@ -115,6 +115,7 @@ typedef struct {
 	GStaticMutex button_lock;
 	GStaticMutex expose_lock;
 	GConfClient *gconf_client;
+	time_t last_poll_ts;
 
 	// door state information
 	dooris_state_t last_state;
@@ -178,6 +179,10 @@ ccchh_dooris_desktop_widget_connection_event(ConIcConnection *connection,
 static gboolean
 fetch_update_cancel_cb (gpointer data);
 
+// async I/O entry function
+static void
+fetch_update_start (CCCHHDoorIsDesktopWidget *self);
+
 // async I/O open callback function
 static void
 fetch_update_async_open_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result,
